<?php
/* 
Plugin Name: Personal Hit Counter
Plugin URI: https://store.devilhunter.net/wordpress-plugin/phc/
Description: The PlugIn shows how many times someone visits your website from a specific browser. This Plugin will automatically match your Theme's CSS style. 
Version: 2.0
Author: Tawhidur Rahman Dear
Author URI: https://www.tawhidurrahmandear.com
Requires at least: 5.5
Requires PHP: 7.4
License: GPLv2 or later
Text Domain: personal-hit-counter
 */


 // Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}
//

function personalhitcounter_by_tawhidurrahmandear_links($plugin_meta, $plugin_file) {
    if ($plugin_file === plugin_basename(__FILE__)) {
        $new_links = array(
            '<a href="https://store.devilhunter.net/wordpress-plugin/phc/" target="_blank">Introduction to Plugin with Documentation</a>',
			'<a href="https://codecanyon.net/item/receptionist-plugin-your-last-visit-was-on-/19311719" target="_blank">Buy Pro Version</a>',
			'<a href="https://store.devilhunter.net/wordpress-plugin/receptionist" target="_blank">Live Preview of Pro Version</a>',
            '<a href="https://wordpress.org/plugins/personal-hit-counter#reviews" target="_blank">Rate and Review at WordPress.org</a>',
            '<a href="https://itsolution.devilhunter.net" target="_blank">Hire for WordPress Web Development</a>',
        );

        // Add the new links to the existing array of links
        $plugin_meta = array_merge($plugin_meta, $new_links);
    }
    return $plugin_meta;
}
add_filter('plugin_row_meta', 'personalhitcounter_by_tawhidurrahmandear_links', 10, 2);

// Load plugin text domain for translations
function receptionistbytawhidurrahmandear_load_textdomain() {
    load_plugin_textdomain('personal-hit-counter', false, dirname(plugin_basename(__FILE__)) . '/languages/');
}
add_action('plugins_loaded', 'receptionistbytawhidurrahmandear_load_textdomain');

// Enqueue the CSS file (no need for JavaScript anymore)
function receptionistbytawhidurrahmandear_enqueue_scripts() {
    // Enqueue the CSS file
    wp_enqueue_style(
        'receptionistbytawhidurrahmandear_style',
        plugins_url('css/personal-hit-counter-styles.css', __FILE__),
        [],
        filemtime(plugin_dir_path(__FILE__) . 'css/personal-hit-counter-styles.css') // Version based on file modification time
    );
}
add_action('wp_enqueue_scripts', 'receptionistbytawhidurrahmandear_enqueue_scripts');

// Add meta box to editors for disabling tracking
function receptionistbytawhidurrahmandear_add_meta_box() {
    add_meta_box(
        'receptionistbytawhidurrahmandear_meta_box',
        esc_html__('Personal Hit Counter Tracking', 'personal-hit-counter'),
        'receptionistbytawhidurrahmandear_meta_box_callback',
        ['post', 'page', 'product'],
        'side',
        'default'
    );
}
add_action('add_meta_boxes', 'receptionistbytawhidurrahmandear_add_meta_box');

// Meta box callback with proper escaping
function receptionistbytawhidurrahmandear_meta_box_callback($post) {
    wp_nonce_field(basename(__FILE__), 'receptionistbytawhidurrahmandear_nonce');
    $value = get_post_meta($post->ID, '_receptionistbytawhidurrahmandear_disable', true);
    echo '<label><input type="checkbox" name="receptionistbytawhidurrahmandear_disable" value="1" ' . checked($value, '1', false) . '> ';
    echo esc_html__('Disable Hit Counter for this item', 'personal-hit-counter');
    echo '</label>';
}

// Save meta box data with validation
function receptionistbytawhidurrahmandear_save_post_meta($post_id) {
if (
    !isset($_POST['receptionistbytawhidurrahmandear_nonce']) || 
    !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['receptionistbytawhidurrahmandear_nonce'])), basename(__FILE__))
) {
    return;
    }
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    if (isset($_POST['receptionistbytawhidurrahmandear_disable'])) {
        update_post_meta($post_id, '_receptionistbytawhidurrahmandear_disable', '1');
    } else {
        delete_post_meta($post_id, '_receptionistbytawhidurrahmandear_disable');
    }
}
add_action('save_post', 'receptionistbytawhidurrahmandear_save_post_meta');

// Track visits, using cookies
function receptionistbytawhidurrahmandear_track_visits() {
    global $post;
    if (isset($post) && !get_post_meta($post->ID, '_receptionistbytawhidurrahmandear_disable', true)) {
        $post_id = $post->ID;
        $visits = [];
if (isset($_COOKIE['receptionistbytawhidurrahmandear_visits'])) {
    // Unslash and sanitize the cookie value
    $cookie_data = sanitize_textarea_field(wp_unslash($_COOKIE['receptionistbytawhidurrahmandear_visits']));
    $visits = json_decode($cookie_data, true);

    // Handle JSON errors
    if (json_last_error() !== JSON_ERROR_NONE) {
        $visits = []; // Reset visits on JSON error
    }
} else {
    $visits = [];
}
        if (isset($visits[$post_id])) {
            $visits[$post_id]['count'] += 1;
            $visits[$post_id]['last_visit'] = current_time('mysql', 1);
        } else {
            $visits[$post_id] = ['count' => 1, 'last_visit' => current_time('mysql', 1)];
        }
        setcookie(
            'receptionistbytawhidurrahmandear_visits',
            wp_json_encode($visits),
            time() + 365 * DAY_IN_SECONDS,
            COOKIEPATH,
            COOKIE_DOMAIN,
            is_ssl(),
            true
        );
    }
}
add_action('template_redirect', 'receptionistbytawhidurrahmandear_track_visits');

// Display visit info with translation and proper escaping
function receptionistbytawhidurrahmandear_display_visit_info($content) {
    global $post;

    if (isset($post) && !get_post_meta($post->ID, '_receptionistbytawhidurrahmandear_disable', true) && is_singular(['post', 'page', 'product'])) {
        $post_id = $post->ID;
        $post_type = get_post_type($post_id);

        // Translate post type for first-time visit message
        $translated_post_type = $post_type === 'post' ? __('post', 'personal-hit-counter') :
                                ($post_type === 'page' ? __('page', 'personal-hit-counter') :
                                ($post_type === 'product' ? __('product', 'personal-hit-counter') : __('item', 'personal-hit-counter')));

        if (isset($_COOKIE['receptionistbytawhidurrahmandear_visits'])) {
            $visits = json_decode(sanitize_textarea_field(wp_unslash($_COOKIE['receptionistbytawhidurrahmandear_visits'])), true);

            // Handle JSON errors
            if (json_last_error() !== JSON_ERROR_NONE) {
                $visits = []; // Reset visits on JSON error
            }

            if (isset($visits[$post_id])) {
                $visit_count = intval($visits[$post_id]['count']);
                $last_visit = esc_attr($visits[$post_id]['last_visit']); // Last visit in UTC
                $visit_text = $visit_count === 1 ? esc_html__('time', 'personal-hit-counter') : esc_html__('times', 'personal-hit-counter');

                // Display visit information with the last visit UTC date in a span for JS conversion
                $visit_info = '<div class="personal-hit-counter-visit-info">';
				$visit_info .= sprintf(
				// Translators: 1. Place type (e.g., 'page'), 2. Number of visits, 3. Visit unit (e.g., 'times').
				'<p>' . esc_html__('You have visited this %1$s %2$d %3$s. Welcome back!', 'personal-hit-counter') . '</p>',
				esc_html($translated_post_type),
				$visit_count,
				$visit_text
				);

                $visit_info .= '</div>';

                return $content . $visit_info;
            } 
        }
        
        // First-time visit message
        return $content . '<div class="personal-hit-counter-visit-info"><p>' . sprintf(
		// Translators: %s is the type of place (e.g., 'page').
            esc_html__('Welcome! It’s your first time on this %s, and we are glad to have you.', 'personal-hit-counter'),
            esc_html($translated_post_type)
        ) . '</p></div>';
    }
    return $content;
}

add_filter('the_content', 'receptionistbytawhidurrahmandear_display_visit_info');